@@ -110,7 +110,7 @@ def test_create_widget_annotation(annotation, expected_type):
     wdg.close()
 
 
-def test_create_widget_annotation_overwritte_parrams():
+def test_create_widget_annotation_overwrite_parrams():
     wdg1 = widgets.create_widget(annotation=widgets.ProgressBar)
     assert isinstance(wdg1, widgets.ProgressBar)
     assert wdg1.visible
@@ -1045,16 +1045,14 @@ def test_literal():
     Lit = Literal[None, "a", 1, True, b"bytes"]
 
     @magicgui
-    def f(x: Lit):
-        ...
+    def f(x: Lit): ...
 
     cbox = f.x
     assert type(cbox) is widgets.ComboBox
     assert cbox.choices == get_args(Lit)
 
     @magicgui
-    def f(x: Set[Lit]):
-        ...
+    def f(x: Set[Lit]): ...
 
     sel = f.x
     assert type(sel) is widgets.Select
